//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionEnumeration.h>

NS_ASSUME_NONNULL_BEGIN

/**
 Key that may exist in the user info dictionary of an NSError instance
 generated by a request to add a topic.
 
 The corresponding value is a `PTDiffusionTopicAddFailReason` instance.

 @since 5.7
 */
extern NSString *const PTDiffusionTopicAddFailReasonErrorKey;

/**
 @brief The reason for failure to add a Topic.
 
 @see PTDiffusionTopicControlFeature

 @since 5.7
 */
@interface PTDiffusionTopicAddFailReason : PTDiffusionEnumeration

/**
 Topic already existed with exactly the same details.

 @since 5.7
 */
+(instancetype)exists;

/**
 Topic already exists at the same path but with different details.

 @since 5.7
 */
+(instancetype)existsMismatch;

/**
 The name of the topic was found to be invalid.

 @since 5.7
 */
+(instancetype)invalidName;

/**
 Some aspect of the details failed validation. This should not normally
 happen for standard attributes but where topic properties have been
 supplied these may be found to be invalid.

 @since 5.7
 */
+(instancetype)invalidDetails;

/**
 A user supplied class could either not be found or could not be
 instantiated at the server.

 @since 5.7
 */
+(instancetype)userCodeError;

/**
 A referenced Topic was not found or was not of the correct type.

 @since 5.7
 */
+(instancetype)topicNotFound;

/**
 The client was denied permission to add a topic of the specified type at
 the given point in the topic hierarchy.

 @since 5.7
 */
+(instancetype)permissionsFailure;

/**
 Initialisation of topic with supplied content failed, possibly because it
 was of the wrong format.

 @since 5.7
 */
+(instancetype)initialiseError;

/**
 An unexpected error occurred whilst attempting to create the Topic. See
 the server log for more details.

 @since 5.7
 */
+(instancetype)unexpectedError;

@end

NS_ASSUME_NONNULL_END
