//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief Attributes applicable to all topic types.
 
 A topic attributes object is immutable.
 
 @see PTDiffusionTopicDetailsBuilder

 @since 5.7
 */
@interface PTDiffusionTopicAttributes : NSObject <NSCopying>

-(instancetype)init NS_UNAVAILABLE;

/**
 The topic reference or a zero length string if not set.

 @since 5.7
 */
@property(nonatomic, readonly) NSString* reference;

/**
 The 'tidy on unsubscribe' flag.
 
 By default, if a client unsubscribes from a topic, it may still receive
 content already queued for it on that topic.
 
 If this option is set to `YES`, when a client unsubscribes from a topic then
 any content for that topic that is still queued for the client is removed.
 There can be a performance overhead to using this option as the client queue
 must be locked whilst content is removed, however it may prove useful for 
 preventing unwanted data being sent to clients.

 @since 5.7
 */
@property(nonatomic, readonly) BOOL tidiesOnUnsubscribe;

/**
 Additional properties.

 @since 5.7
 */
@property(nonatomic, readonly) NSDictionary<NSString *, NSString *>* properties;

/**
 Compares the receiver to the given topic attributes.

 @param topicAttributes The topic attributes object with which to compare the receiver.

 @return `YES` if the topic attributes is equal to the receiver, otherwise `NO`.

 @since 5.7
 */
-(BOOL)isEqualToTopicAttributes:(nullable PTDiffusionTopicAttributes *)topicAttributes;

@end

NS_ASSUME_NONNULL_END
