//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionTopicTreeRegistration.h>

NS_ASSUME_NONNULL_BEGIN

/**
 @brief Listener for topic events from the server.
 
 @see PTDiffusionTopicControlFeature

 @since 5.7
 */
@protocol PTDiffusionTopicEventListener <PTDiffusionTopicTreeRegistrationDelegate>

@optional

/**
 A topic that previously had no subscribers now has at least one.

 @param registration The topic tree registration for which this listener applies.

 @param topicPath The path of the topic.

 @since 5.7
 */
-(void)diffusionTopicTreeRegistration:(PTDiffusionTopicTreeRegistration *)registration
           hasSubscribersForTopicPath:(NSString *)topicPath;

/**
 A topic that previously had some subscribers now has none.

 @param registration The topic tree registration for which this listener applies.

 @param topicPath The path of the topic.

 @since 5.7
 */
-(void)diffusionTopicTreeRegistration:(PTDiffusionTopicTreeRegistration *)registration
         hasNoSubscribersForTopicPath:(NSString *)topicPath;

@end

NS_ASSUME_NONNULL_END
